﻿using Microsoft.Azure.Search;
using Microsoft.Azure.Search.Models;
using Soltisweb.Models;
using System;
using System.Collections.Generic;

namespace Soltisweb.Helpers
{
    public class AzureSearchHelper
    {
        private static ISearchServiceClient _searchClient;
        private static ISearchIndexClient _indexClient;

        public static DocumentSearchResult Search(ProjectOptions _projectoptions, SearchFormData data)
        {
            // Execute search based on query string
            try
            {
                _searchClient = new SearchServiceClient(_projectoptions.AzureSearchService, new SearchCredentials(_projectoptions.AzureSearchAPIKey));
                _indexClient = _searchClient.Indexes.GetClient(_projectoptions.AzureSearchIndexName);

                //Build the SearchParameter object
                SearchParameters sp = new SearchParameters();

                sp.SearchMode = data.SearchMode;

                sp.SearchFields = new[] { "Name", "Location" };

                //Check if highlights should be returned
                if (data.ShowHighlights)
                {
                    sp.HighlightFields = new List<string> { "Name", "Location" };
                    sp.HighlightPreTag = "<span class='highlight'>";
                    sp.HighlightPostTag = "</span>";
                }

                sp.Facets = new List<string> { "Type" };

                if(data.FilterBy != null)
                {
                    sp.Filter = sp.Filter = "Type eq '" + data.FilterBy + "'";
                }

                if (data.OrderBy != null)
                {
                    if (data.OrderBy != "")
                    {
                        sp.OrderBy = data.OrderBy.Split(',');
                    }
                }

                return _indexClient.Documents.Search(data.SearchValue, sp);
            }
            catch (Exception)
            {
                return null;
            }
        }

    }
}
